#[non_exhaustive]pub enum Request {
Stop,
GetCosmicToplevel {
cosmic_toplevel: New<ZcosmicToplevelHandleV1>,
foreign_toplevel: ExtForeignToplevelHandleV1,
},
}wayland_platform and crate feature server only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Stop
stop sending events
This request indicates that the client no longer wishes to receive events for new toplevels. However, the compositor may emit further toplevel_created events until the finished event is emitted.
The client must not send any more requests after this one.
Note: This request isn’t necessary for clients binding version 2 of this protocol and will be ignored.
GetCosmicToplevel
get cosmic toplevel extension object
Request a zcosmic_toplevel_handle_v1 extension object for an existing ext_foreign_toplevel_handle_v1.
All initial properties of the toplevel (states, etc.) will be sent immediately after this event via the corresponding events in zcosmic_toplevel_handle_v1.
Only available since version 2 of the interface
Implementations